@@ -1,10 +1,8 @@
-library(changepoint)
-library(strucchange)
-
 context('test changepoint')
 
 test_that('fortify.cpt works for AirPassengers', {
-
+  skip_if_not_installed("changepoint")
+  library(changepoint)
   # mean
   result <- changepoint::cpt.mean(AirPassengers)
 
@@ -46,7 +44,8 @@ test_that('fortify.cpt works for AirPassengers', {
 
 
 test_that('fortify.breakpoints works for Nile', {
-
+  skip_if_not_installed("strucchange")
+  library(strucchange)
   bp.nile <- strucchange::breakpoints(Nile ~ 1)
   p <- ggplot2::autoplot(breakpoints(bp.nile, breaks = 2), data = Nile)
   expect_true(is(p, 'ggplot'))
