@@ -1,6 +1,7 @@
 context('test forecast')
 
 test_that('fortify.forecast works for AirPassengers', {
+  skip_if_not_installed("forecast")
   d.arima <- forecast::auto.arima(AirPassengers)
   d.forecast <- forecast::forecast(d.arima, level = c(95), h = 50)
 
@@ -39,7 +40,7 @@ test_that('fortify.forecast works for AirPassengers', {
 })
 
 test_that('fortify.arfima works for austres', {
-
+  skip_if_not_installed("forecast")
   fortified <- ggplot2::fortify(forecast::arfima(austres))
   expect_equal(is.data.frame(fortified), TRUE)
 
@@ -58,6 +59,7 @@ test_that('fortify.arfima works for austres', {
 })
 
 test_that('fortify.ets works for UKgas', {
+  skip_if_not_installed("forecast")
   result <- forecast::ets(UKgas)
   fortified <- ggplot2::fortify(result)
   expect_equal(is.data.frame(fortified), TRUE)
@@ -71,6 +73,7 @@ test_that('fortify.ets works for UKgas', {
 })
 
 test_that('fortify.bats works for UKgas', {
+  skip_if_not_installed("forecast")
   result <- forecast::bats(UKgas, use.parallel = FALSE)
   fortified <- ggplot2::fortify(result)
   expect_equal(is.data.frame(fortified), TRUE)
@@ -84,10 +87,11 @@ test_that('fortify.bats works for UKgas', {
 })
 
 test_that('fortify.ets works for austres', {
+  skip_if_not_installed("forecast")
   result <- forecast::ets(austres)
   fortified <- ggplot2::fortify(result)
   expect_equal(is.data.frame(fortified), TRUE)
-  if(result$components[3] == "N")
+  if (result$components[3] == "N")
     expected_names <- c('Index', 'Data', 'Fitted', 'Residuals', 'Level', 'Slope')
   else
     expected_names <- c('Index', 'Data', 'Fitted', 'Residuals', 'Level', 'Slope', 'Season')
@@ -100,6 +104,7 @@ test_that('fortify.ets works for austres', {
 })
 
 test_that('fortify.bats works for austres', {
+  skip_if_not_installed("forecast")
   result <- forecast::bats(austres, use.parallel = FALSE)
   fortified <- ggplot2::fortify(result)
   expect_equal(is.data.frame(fortified), TRUE)
@@ -111,3 +116,52 @@ test_that('fortify.bats works for austres', {
   p <- ggplot2::autoplot(result)
   expect_true(is(p, 'ggplot'))
 })
+
+test_that('fortify.forecast works for AirPassengers', {
+  skip_if_not_installed("forecast")
+  d.arima <- forecast::auto.arima(AirPassengers)
+  d.forecast <- forecast::forecast(d.arima, level = c(95), h = 50)
+
+  fortified <- fortify(d.forecast)
+  expected_names <- c('Index', 'Data', 'Fitted', 'Point Forecast',
+                      'Lo 95', 'Hi 95')
+  expect_equal(names(fortified), expected_names)
+  expect_equal(fortified$Index[1], as.Date('1949-01-01'))
+  expect_equal(fortified$Index[194], as.Date('1965-02-01'))
+  p <- autoplot(d.forecast)
+  expect_true(inherits(p, 'ggplot'))
+
+  fortified <- fortify(d.forecast, ts.connect = TRUE)
+  expected_names <- c('Index', 'Data', 'Fitted', 'Point Forecast',
+                      'Lo 95', 'Hi 95')
+  expect_equal(names(fortified), expected_names)
+  expect_equal(fortified$Index[1], as.Date('1949-01-01'))
+  expect_equal(fortified$Index[194], as.Date('1965-02-01'))
+  p <- autoplot(d.forecast, ts.connect = TRUE)
+  expect_true(inherits(p, 'ggplot'))
+})
+
+
+test_that('fortify.ets works for AirPassengers', {
+  skip_if_not_installed("forecast")
+  d.arima <- forecast::auto.arima(AirPassengers)
+  d.forecast <- forecast::forecast(d.arima, level = c(95), h = 50)
+
+  fortified <- fortify(d.forecast)
+  expected_names <- c('Index', 'Data', 'Fitted', 'Point Forecast',
+                      'Lo 95', 'Hi 95')
+  expect_equal(names(fortified), expected_names)
+  expect_equal(fortified$Index[1], as.Date('1949-01-01'))
+  expect_equal(fortified$Index[194], as.Date('1965-02-01'))
+  p <- autoplot(d.forecast)
+  expect_true(inherits(p, 'ggplot'))
+
+  fortified <- fortify(d.forecast, ts.connect = TRUE)
+  expected_names <- c('Index', 'Data', 'Fitted', 'Point Forecast',
+                      'Lo 95', 'Hi 95')
+  expect_equal(names(fortified), expected_names)
+  expect_equal(fortified$Index[1], as.Date('1949-01-01'))
+  expect_equal(fortified$Index[194], as.Date('1965-02-01'))
+  p <- autoplot(d.forecast, ts.connect = TRUE)
+  expect_true(inherits(p, 'ggplot'))
+})
