@@ -21,6 +21,8 @@ test_that('fortify.stl works for AirPassengers', {
 })
 
 test_that('fortify.Arima works for AirPassengers', {
+  skip_if_not_installed("forecast")
+  skip_if_not_installed("fGarch")
   fortified <- ggplot2::fortify(ar(AirPassengers))
   expect_true(is.data.frame(fortified))
   expected_names <- c('Index', 'Data', 'Fitted', 'Residuals')
